@@ -21,7 +21,7 @@ seconds_in_hour = 3600
 seconds_in_half_hour = 1800
 fillvalue_double = 9.969209968386869e+36
 fillvalue_float = 9.96921e+36
-jaws_version = '0.9.2'
+jaws_version = '0.9.3'
 
 ###############################################################################
 
@@ -179,6 +179,9 @@ def load_dataset_attributes(name, ds, args, **kwargs):
         for var in pressure_vars:
             ds[var].attrs.update([('units', 'hPa')])
 
+    if name == 'nsidc' and kwargs.pop('year1900'):
+        ds['time'].attrs.update([('units', 'seconds since 1900-01-01 00:00:00')])
+
     for column in columns:
         if column in ('qc1', 'qc9', 'qc17', 'qc25'):
             load_dataset_attributes_gcnet_qltyctrl(name, ds)
